@@ -1,11 +1,11 @@
 #!/bin/bash
 # Author: Steven Shiau <steven _at_ nchc org tw>
 # License: GPL
-# Description: Program to make USB flash drive (FAT format) bootable by syslinux
+# Description: Program to make USB flash drive (FAT, EXT, BTRFS or NTFS) bootable by syslinux or extlinux
 
 # 1. Checking if partition table correct (on boundary, bootable)
 # 2. cat mbr
-# 3. syslinux -fs
+# 3. "syslinux -f -i" or "extlinux -i"
 #
 # Append PATH
 export PATH=/sbin:/usr/sbin:/bin:/usr/bin:$PATH
@@ -30,7 +30,7 @@ msg_do_you_want_to_make_it_bootable="Do you want to mark it as bootable ?"
 USAGE() {
    echo "Usage: $prog partition_device"
    echo "Ex:" 
-   echo "To make /dev/sde1 bootable on Linux:"
+   echo "To make /dev/sde1 bootable on GNU/Linux:"
    echo "  $prog /dev/sde1"
 }
 # Check if root or not
@@ -106,7 +106,14 @@ if [ -z "$target_part" ]; then
 fi
 if ! type parted &>/dev/null; then
   [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
-  echo "Parted was not found on this GNU/Linux system. Please install it."
+  echo 'Program "parted" was not found on this GNU/Linux system. Please install it.'
+  [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+  echo "Program terminated!"
+  exit 1
+fi
+if ! type blkid &>/dev/null; then
+  [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
+  echo 'Program "blkid" was not found on this GNU/Linux system. Please install it.'
   [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
   echo "Program terminated!"
   exit 1
@@ -134,6 +141,7 @@ if [ -z "$(LC_ALL=C parted -s $target_disk print | grep -iE "^Partition Table:"
   LC_ALL=C parted -s $target_disk print
   [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
   echo "This program is for making a bootable disk with MBR partition table."
+  echo "For GPT disk, there is no need to run this program. Just make sure the partition is FAT32 with ID=ef00 and all the files are copied on that. That's all."
   echo "Program terminated!"
   exit 1
 fi
